@@ -70,34 +70,34 @@ sub marc_map {
     my @vals = ();
 
     for my $var (@$record) {
-        next if $var->[0] !~ /$attrs->{field_regex}/;
-        next if defined $attrs->{ind1} && $var->[1] ne $attrs->{ind1};
-        next if defined $attrs->{ind2} && $var->[2] ne $attrs->{ind2};
+    	next if $var->[0] !~ /$attrs->{field_regex}/;
+    	next if defined $attrs->{ind1} && $var->[1] ne $attrs->{ind1};
+    	next if defined $attrs->{ind2} && $var->[2] ne $attrs->{ind2};
 
-        my $v;
+    	my $v;
 
-        if ($var->[0] =~ /LDR|00./) {
-            $v = $add_subfields->($var,3);
-        }
-        elsif ($var->[5] eq '_') {
-            $v = $add_subfields->($var,5);
-        }
-        else {
-            $v = $add_subfields->($var,3);
-        }
+    	if ($var->[0] =~ /LDR|00./) {
+    		$v = $add_subfields->($var,3);
+    	}
+    	elsif (defined $var->[5] && $var->[5] eq '_') {
+    		$v = $add_subfields->($var,5);
+    	}
+    	else {
+    		$v = $add_subfields->($var,3);
+    	}
 
-        if (@$v) {
-            if (!$split) {
-                $v = join $join_char, @$v;
+    	if (@$v) {
+    		if (!$split) {
+    			$v = join $join_char, @$v;
 
-                if (defined(my $off = $attrs->{from})) {
-                    my $len = defined $attrs->{to} ? $attrs->{to} - $off + 1 : 1;
-                    $v = substr($v,$off,$len);
-                }
-            }
-        }
+    			if (defined(my $off = $attrs->{from})) {
+    				my $len = defined $attrs->{to} ? $attrs->{to} - $off + 1 : 1;
+    				$v = substr($v,$off,$len);
+    			}
+    		}
+    	}
 
-        push (@vals,$v) if ( (ref $v eq 'ARRAY' && @$v) || (ref $v eq '' && length $v ));
+    	push (@vals,$v) if ( (ref $v eq 'ARRAY' && @$v) || (ref $v eq '' && length $v ));
     }
 
     if (wantarray) {
